==> ejc-zhengyuan-impl-3.0.0-20241227.024427-13-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanMonographVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 专著
 * 
 * @author generator
 * 
 */
public class KeyanMonographVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String monographName; // 著作名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date publicationTime; // 出版时间
    private String author; // 作者
    private String countryInOut; // 国内/外
    private String authorRank; // 本单位作者位次
    private String publisherName; // 出版社名称
    private String category; // 类别
    private String isbnNo; // ISBN号
    private String cipNo; // CIP数据号
    private String totalWordsNumber; // 总字数
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getMonographName() {
        return monographName;
    }

    public void setMonographName(String monographName) {
        this.monographName = monographName;
    }
    public Date getPublicationTime() {
        return publicationTime;
    }

    public void setPublicationTime(Date publicationTime) {
        this.publicationTime = publicationTime;
    }
    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }
    public String getCountryInOut() {
        return countryInOut;
    }

    public void setCountryInOut(String countryInOut) {
        this.countryInOut = countryInOut;
    }
    public String getAuthorRank() {
        return authorRank;
    }

    public void setAuthorRank(String authorRank) {
        this.authorRank = authorRank;
    }
    public String getPublisherName() {
        return publisherName;
    }

    public void setPublisherName(String publisherName) {
        this.publisherName = publisherName;
    }
    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }
    public String getIsbnNo() {
        return isbnNo;
    }

    public void setIsbnNo(String isbnNo) {
        this.isbnNo = isbnNo;
    }
    public String getCipNo() {
        return cipNo;
    }

    public void setCipNo(String cipNo) {
        this.cipNo = cipNo;
    }
    public String getTotalWordsNumber() {
        return totalWordsNumber;
    }

    public void setTotalWordsNumber(String totalWordsNumber) {
        this.totalWordsNumber = totalWordsNumber;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20250821.081133-43-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanMonographVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 专著
 * 
 * @author generator
 * 
 */
public class KeyanMonographVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String monographName; // 著作名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date publicationTime; // 出版时间
    private String author; // 作者
    private String countryInOut; // 国内/外
    private String authorRank; // 本单位作者位次
    private String publisherName; // 出版社名称
    private String category; // 类别
    private String isbnNo; // ISBN号
    private String cipNo; // CIP数据号
    private String totalWordsNumber; // 总字数
    private String remarks; // 备注

    private String errorMsg; // 导入错误信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getMonographName() {
        return monographName;
    }

    public void setMonographName(String monographName) {
        this.monographName = monographName;
    }
    public Date getPublicationTime() {
        return publicationTime;
    }

    public void setPublicationTime(Date publicationTime) {
        this.publicationTime = publicationTime;
    }
    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }
    public String getCountryInOut() {
        return countryInOut;
    }

    public void setCountryInOut(String countryInOut) {
        this.countryInOut = countryInOut;
    }
    public String getAuthorRank() {
        return authorRank;
    }

    public void setAuthorRank(String authorRank) {
        this.authorRank = authorRank;
    }
    public String getPublisherName() {
        return publisherName;
    }

    public void setPublisherName(String publisherName) {
        this.publisherName = publisherName;
    }
    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }
    public String getIsbnNo() {
        return isbnNo;
    }

    public void setIsbnNo(String isbnNo) {
        this.isbnNo = isbnNo;
    }
    public String getCipNo() {
        return cipNo;
    }

    public void setCipNo(String cipNo) {
        this.cipNo = cipNo;
    }
    public String getTotalWordsNumber() {
        return totalWordsNumber;
    }

    public void setTotalWordsNumber(String totalWordsNumber) {
        this.totalWordsNumber = totalWordsNumber;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    
}
